==> maxdb-7.5.00_7.5.00.24.orig.tar.gz: maxdb-7.5.00-7.5.00.24.orig/MaxDB_ORG/sys/src/SAPDB/XML/IndexingDeclarationLib/XMLIDMLib_HtmlTemplate_HeaderEmbedded.cpp <==
/****************************************************************************

  module      : XMLIDMLib_HtmlTemplate_HeaderEmbedded.cpp

  -------------------------------------------------------------------------

  responsible : Daniel Kirmse

  special area: 
  description : 


  last changed: 2001-06-26  16:19
  see also    : 

  -------------------------------------------------------------------------


  ========== licence begin  GPL
  Copyright (c) 2001-2004 SAP AG

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  ========== licence end

*****************************************************************************/

	/*===================================================================
	// Includes
	//===================================================================*/
	#include "SAPDB/XML/IndexingDeclarationLib/XMLIDMLib_HtmlTemplate_HeaderEmbedded.hpp"



	XMLIDMLib_HtmlTemplate_HeaderEmbedded::XMLIDMLib_HtmlTemplate_HeaderEmbedded(sapdbwa_WebAgent &wa,
																 				 sapdbwa_HttpRequest &req) 
		                  : Tools_Template ( wa, (const unsigned char*)TEMPLATE_EMBEDDED_HEADER )
	{ 
		strcpy(_serviceName,wa.GetServiceName());
	} 


	XMLIDMLib_HtmlTemplate_HeaderEmbedded::~XMLIDMLib_HtmlTemplate_HeaderEmbedded()
	{
	}

	XMLIDMLIB_Int2 XMLIDMLib_HtmlTemplate_HeaderEmbedded::askForWriteCount(const Tools_DynamicUTF8String & szName)
	{
		return 1;
	} 


	Tools_DynamicUTF8String XMLIDMLib_HtmlTemplate_HeaderEmbedded::askForValue (const Tools_DynamicUTF8String & szName)
	{
		return (Tools_DynamicUTF8String::ConstPointer)_serviceName;
	}

==> maxdb-7.5.00_7.5.00.34.orig.tar.gz: maxdb-7.5.00-7.5.00.34.orig/MaxDB_ORG/sys/src/SAPDB/XML/IndexingDeclarationLib/XMLIDMLib_HtmlTemplate_HeaderEmbedded.cpp <==
/****************************************************************************

  module      : XMLIDMLib_HtmlTemplate_HeaderEmbedded.cpp

  -------------------------------------------------------------------------

  responsible : Daniel Kirmse

  special area: 
  description : 


  last changed: 2001-06-26  16:19
  see also    : 

  -------------------------------------------------------------------------


    ========== licence begin  GPL
    Copyright (c) 2001-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end


*****************************************************************************/

	/*===================================================================
	// Includes
	//===================================================================*/
	#include "SAPDB/XML/IndexingDeclarationLib/XMLIDMLib_HtmlTemplate_HeaderEmbedded.hpp"



	XMLIDMLib_HtmlTemplate_HeaderEmbedded::XMLIDMLib_HtmlTemplate_HeaderEmbedded(sapdbwa_WebAgent &wa,
																 				 sapdbwa_HttpRequest &req) 
		                  : Tools_Template ( wa, (const unsigned char*)TEMPLATE_EMBEDDED_HEADER )
	{ 
		strcpy(_serviceName,wa.GetServiceName());
	} 


	XMLIDMLib_HtmlTemplate_HeaderEmbedded::~XMLIDMLib_HtmlTemplate_HeaderEmbedded()
	{
	}

	XMLIDMLIB_Int2 XMLIDMLib_HtmlTemplate_HeaderEmbedded::askForWriteCount(const Tools_DynamicUTF8String & szName)
	{
		return 1;
	} 


	Tools_DynamicUTF8String XMLIDMLib_HtmlTemplate_HeaderEmbedded::askForValue (const Tools_DynamicUTF8String & szName)
	{
		return (Tools_DynamicUTF8String::ConstPointer)_serviceName;
	}
